import { describe, it, expect } from 'vitest';
import parsePhone from 'src/filters/parsePhone';

describe('parsePhone filter', () => {
    it('no phone', () => {
        const resultado = parsePhone(null, '34');
        expect(resultado).toBe(undefined);
    });
    it('no phone and no prefix', () => {
        const resultado = parsePhone(null, null);
        expect(resultado).toBe(undefined);
    });
    it("adds prefix +34 if it doesn't have one", () => {
        const resultado = parsePhone('123456789', '34');
        expect(resultado).toBe('34123456789');
    });

    it('maintains prefix +34 if it is already correct', () => {
        const resultado = parsePhone('+34123456789', '34');
        expect(resultado).toBe('34123456789');
    });

    it('converts prefix 0034 to +34', () => {
        const resultado = parsePhone('0034123456789', '34');
        expect(resultado).toBe('34123456789');
    });

    it('converts prefix 34 without symbol to +34', () => {
        const resultado = parsePhone('34123456789', '34');
        expect(resultado).toBe('34123456789');
    });

    it('replaces incorrect prefix with the correct one', () => {
        const resultado = parsePhone('+44123456789', '34');
        expect(resultado).toBe('44123456789');
    });
});
